unit Unit1;

// This little example shows how to create the illusion
// of your program painting directly on the desktop!
// If you have any ideas for improvements, please send
// the new version to me - you will ofcourse be credited.
// Particularly I'm looking for methods to make the
// drawing faster, although it's not HORRIBLY slow now.
//
// Note that: the illusion is lost if something changes
// underneath your form - this means that this effects
// is probably only useful for splash screens etc.
// If you can figure out how to make the image repaint
// when something changes underneath it, please write!
// Also note that I'm assuming the client area of the
// form is exactly the same size as the map and mask
// images.
//
// You can e-mail me at mus303@yahoo.com

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls;

type
  TMyForm = class(TForm)
    CloseButton: TButton;
    MyImage: TImage;
    CopyButton: TButton;
    LogoMap: TImage;
    LogoMask: TImage;
    procedure FormCreate(Sender: TObject);
    procedure CloseButtonClick(Sender: TObject);
    procedure CopyButtonClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  MyForm: TMyForm;

implementation

{$R *.DFM}

procedure TMyForm.FormCreate(Sender: TObject);
begin
  // as the form is created, make sure it doesn't
  // paint its client area ...
  Brush.Style:=bsClear;
end;

procedure TMyForm.CloseButtonClick(Sender: TObject);
begin
  halt;
end;

procedure TMyForm.CopyButtonClick(Sender: TObject);
var
  newBitmap: TBitmap; // We need this to work with.
  ScreenDC: HDC;      // This will let us access the 'desktop'.
  REOrg: TPoint;      // Origin of our Form's client area.
  X,Y: Integer;       // Holds coordinates.
  P,I,M: PByteArray;  // For faster (than Pixels[]) access.
begin
  // Create a new bitmap:
  newBitmap:=TBitmap.Create;
  try
    // Now assign this bitmap to our image:
    MyImage.Picture.Graphic:=newBitmap;
    // Get our form's width/height for the new image:
    MyImage.Picture.Graphic.Width:=MyForm.ClientWidth;
    MyImage.Picture.Graphic.Height:=MyForm.ClientHeight;
    // Get the forms origin:
    REOrg:=MyForm.ClientToScreen(Point(0,0));
    // Allow access to the desktop:
    ScreenDC:=GetDC(0);
    try
      // Copy the desktop area under the form, to our image:
      BitBlt(MyImage.Picture.Bitmap.Canvas.Handle,0,0,MyForm.ClientWidth,MyForm.ClientHeight,ScreenDC,REOrg.X, REOrg.Y, SRCCOPY);
    finally
      // Release the desktop DC again:
      ReleaseDC(0, ScreenDC);
    end;
  finally
    // Release our temporary bitmap:
    newBitmap.Free;
  end;
  // Convert our images to true colour:
  MyImage.Picture.Bitmap.HandleType:=bmDIB;
  MyImage.Picture.Bitmap.PixelFormat:=pf24Bit;
  LogoMap.Picture.Bitmap.HandleType:=bmDIB;
  LogoMap.Picture.Bitmap.PixelFormat:=pf24Bit;
  LogoMask.Picture.Bitmap.HandleType:=bmDIB;
  LogoMask.Picture.Bitmap.PixelFormat:=pf24Bit;
  // Process the pixels:
  For Y:=0 to Height-1 do begin
    P:=MyImage.Picture.Bitmap.ScanLine[Y];
    I:=LogoMap.Picture.Bitmap.ScanLine[Y];
    M:=LogoMask.Picture.Bitmap.ScanLine[Y];
    For X:=0 to (Width)*3-1 do
      P[X]:=(P[X]*(256-M[X])+I[X]*(M[X])) div 256;
  end;
  // Make the image visible:
  MyImage.Visible:=True;
end;

end.

